import React, { useState } from "react";

// VideoModal Component for both YouTube and Drone footage
const VideoModal = ({ isOpen, onClose, children }) => {
  if (!isOpen) return null;
  
  return (
    <div className="fixed inset-0 z-[60] flex items-center justify-center bg-black bg-opacity-75 p-4">
      <div className="relative bg-white rounded-lg shadow-xl w-full max-w-4xl">
        <button
          onClick={onClose}
          className="absolute -top-4 -right-4 bg-white rounded-full p-2 shadow-lg z-50"
          aria-label="Close video"
        >
          <svg xmlns="http://www.w3.org/2000/svg" className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
          </svg>
        </button>
        <div className="p-4">
          {children}
        </div>
      </div>
    </div>
  );
};

const DroneVideoCard = () => (
  <div className="bg-white p-2 rounded-lg">
    <h3 className="text-lg font-semibold mb-2">Drone Footage</h3>
    <div className="aspect-video bg-gray-100 rounded-lg mb-2 flex items-center justify-center">
      <div className="text-gray-500">
        <svg className="w-12 h-12 mx-auto mb-1" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 10l4.553-2.276A1 1 0 0121 8.618v6.764a1 1 0 01-1.447.894L15 14M5 18h8a2 2 0 002-2V8a2 2 0 00-2-2H5a2 2 0 00-2 2v8a2 2 0 002 2z" />
        </svg>
        <p className="text-sm text-center">Aerial View of Property</p>
      </div>
    </div>
  </div>
);

// Main PropertyDetailsModal Component
const PropertyDetailsModal = ({ property, onClose }) => {
  const [selectedMainImage, setSelectedMainImage] = useState(0);
  const [showYouTubeModal, setShowYouTubeModal] = useState(false);
  const [showDroneModal, setShowDroneModal] = useState(false);

  if (!property) return null;

  const backendBaseUrl = "http://127.0.0.1:8000";

  // Separate main images and thumbnails processing
  const mainImages = property.images.map(photo => 
    `${backendBaseUrl}/user-img/user-post-main-img/${photo.mainImg}`
  );
  
  const thumbnailImages = property.images.flatMap(photo =>
    photo.thumbImages.map(thumb => 
      `${backendBaseUrl}/user-img/user-post-img-thumb/${thumb}`
    )
  );

  const handleYouTubeClick = () => {
    setShowYouTubeModal(true);
  };

  const handleDroneVideoClick = () => {
    setShowDroneModal(true);
  };

  return (
    <>
      <div className="fixed inset-0 z-50 flex items-center justify-center bg-black bg-opacity-50 p-4 overflow-y-auto">
        <div className="bg-white rounded-lg shadow-xl max-w-4xl w-full mx-auto my-8">
          <div className="p-6">
            {/* Close Button */}
            <div className="flex justify-between items-center border-b pb-4 sticky top-0 bg-white z-10">
              <h2 className="text-xl font-semibold text-gray-900">Property Details</h2>
              <button
                onClick={onClose}
                className="text-gray-500 hover:text-gray-700"
                aria-label="Close modal"
              >
                <svg xmlns="http://www.w3.org/2000/svg" className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                </svg>
              </button>
            </div>

            {/* Scrollable Content Container */}
            <div className="max-h-[70vh] overflow-y-auto">
              {/* Main Image Display */}
              {mainImages.length > 0 && (
                <div className="mt-4">
                  <div className="w-full aspect-[16/9] rounded-lg overflow-hidden">
                    <img
                      src={mainImages[selectedMainImage]}
                      alt={`Main Property Image ${selectedMainImage + 1}`}
                      className="w-full h-full object-cover"
                    />
                  </div>
                  
                </div>
              )}
              {/* Thumbnail Images Section */}
              {thumbnailImages.length > 0 && (
                <div className="mt-2">
                  <h3 className="text-lg font-medium text-gray-900 mb-3">Additional Images</h3>
                  <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 gap-4">
                    {thumbnailImages.map((img, index) => (
                      <div
                        key={`thumb-${index}`}
                        className="aspect-[4/3] rounded-lg overflow-hidden border border-gray-200 shadow-sm hover:shadow-md transition-shadow duration-200"
                      >
                        <img
                          src={img}
                          alt={`Thumbnail ${index + 1}`}
                          className="w-full h-full object-cover"
                          loading="lazy"
                        />
                      </div>
                    ))}
                  </div>
                </div>
              )}

              {/* Property Details Table */}
              <div className="mt-6 overflow-x-auto">
                <table className="w-full text-sm text-left rtl:text-right text-gray-500">
                  <thead className="text-xs text-gray-700 uppercase bg-gray-50 sticky top-0 z-10">
                    <tr>
                      <th scope="col" className="px-6 py-3">Location</th>
                      <th scope="col" className="px-6 py-3">Price</th>
                      <th scope="col" className="px-6 py-3">Ph.no</th>
                      <th scope="col" className="px-6 py-3">Status</th>
                      <th scope="col" className="px-6 py-3">Type</th>
                      <th scope="col" className="px-6 py-3">Listed Date</th>
                    </tr>
                  </thead>
                  <tbody>
                    <tr className="bg-white border-b hover:bg-gray-50">
                      <td className="px-6 py-4">{property.location}</td>
                      <td className="px-6 py-4">{property.price}</td>
                      <td className="px-6 py-4">{property.number}</td>
                      <td className="px-6 py-4">{property.status}</td>
                      <td className="px-6 py-4">{property.type}</td>
                      <td className="px-6 py-4">{property.date}</td>
                    </tr>
                  </tbody>
                </table>

                {/* Additional Property Details */}
                <div className="mt-6 grid grid-cols-1 md:grid-cols-2 gap-4">
                  <div className="bg-gray-50 p-4 rounded-lg">
                    <h3 className="font-semibold text-gray-900 mb-2">Property Specifications</h3>
                    <dl className="space-y-2">
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Dimensions:</dt>
                        <dd className="text-gray-900">{property.dimensions}</dd>
                      </div>
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Land Size:</dt>
                        <dd className="text-gray-900">{property.landSize}</dd>
                      </div>
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Plot Facing:</dt>
                        <dd className="text-gray-900">{property.facing}</dd>
                      </div>
                    </dl>
                  </div>

                  <div className="bg-gray-50 p-4 rounded-lg">
                    <h3 className="font-semibold text-gray-900 mb-2">Distance Information</h3>
                    <dl className="space-y-2">
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Airport:</dt>
                        <dd className="text-gray-900">{property?.distances?.airport || null} km</dd>
                      </div>
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Railway:</dt>
                        <dd className="text-gray-900">{property?.distances?.railway} km</dd>
                      </div>
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Bus Stand:</dt>
                        <dd className="text-gray-900">{property?.distances?.bus_stand} km</dd>
                      </div>
                      <div className="flex justify-between">
                        <dt className="text-gray-600">Hospital:</dt>
                        <dd className="text-gray-900">{property?.distances?.hospital} km</dd>
                      </div>
                      <div className="flex justify-between">
                        <dt className="text-gray-600">School:</dt>
                        <dd className="text-gray-900">{property?.distances?.school} km</dd>
                      </div>
                    </dl>
                  </div>
                </div>

                {/* Video Buttons Section */}
                <div className="mt-6 grid grid-cols-1 md:grid-cols-2 gap-4">
                  <button
                    onClick={handleYouTubeClick}
                    className="bg-red-600 text-white px-4 py-3 rounded-md hover:bg-red-700 transition-colors duration-200 flex items-center justify-center gap-2"
                  >
                    <svg className="w-5 h-5" viewBox="0 0 24 24" fill="currentColor">
                      <path d="M19.615 3.184c-3.604-.246-11.631-.245-15.23 0-3.897.266-4.356 2.62-4.385 8.816.029 6.185.484 8.549 4.385 8.816 3.6.245 11.626.246 15.23 0 3.897-.266 4.356-2.62 4.385-8.816-.029-6.185-.484-8.549-4.385-8.816zm-10.615 12.816v-8l8 3.993-8 4.007z"/>
                    </svg>
                    View YouTube Video
                  </button>

                  <button 
                    onClick={handleDroneVideoClick}
                    className="bg-blue-600 text-white px-4 py-3 rounded-md hover:bg-blue-700 transition-colors duration-200 flex items-center justify-center gap-2"
                  >
                    <svg className="w-5 h-5" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2">
                      <path d="M14.5 10c-.83 0-1.5-.67-1.5-1.5v-5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5z"/>
                      <path d="M20.5 10H19V8.5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"/>
                      <path d="M9.5 14c.83 0 1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5S8 21.33 8 20.5v-5c0-.83.67-1.5 1.5-1.5z"/>
                      <path d="M3.5 14H5v1.5c0 .83-.67 1.5-1.5 1.5S2 16.33 2 15.5 2.67 14 3.5 14z"/>
                      <path d="M14 14.5c0-.83.67-1.5 1.5-1.5h5c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5h-5c-.83 0-1.5-.67-1.5-1.5z"/>
                      <path d="M15.5 19H14v1.5c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5z"/>
                      <path d="M10 9.5C10 8.67 9.33 8 8.5 8h-5C2.67 8 2 8.67 2 9.5S2.67 11 3.5 11h5c.83 0 1.5-.67 1.5-1.5z"/>
                      <path d="M8.5 5H10V3.5C10 2.67 9.33 2 8.5 2S7 2.67 7 3.5 7.67 5 8.5 5z"/>
                    </svg>
                    View Drone Footage
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* YouTube Video Modal */}
      <VideoModal 
        isOpen={showYouTubeModal} 
        onClose={() => setShowYouTubeModal(false)}
      >
        <div className="aspect-video">
          <iframe 
            className="w-full h-full"
            src={property.youtube}
            title="YouTube video player"
            frameBorder="0"
            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
            referrerPolicy="strict-origin-when-cross-origin"
            allowFullScreen
          />
        </div>
      </VideoModal>

      {/* Drone Video Modal */}
      <VideoModal 
        isOpen={showDroneModal} 
        onClose={() => setShowDroneModal(false)}
      >
        <DroneVideoCard />
      </VideoModal>
    </>
  );
};

export default PropertyDetailsModal;
